==> trosnoth-1.0.0.tar.gz: trosnoth-1.0.0/trosnoth/src/gui/fonts/font.py <==
# Trosnoth (UberTweak Platform Game)
# Copyright (C) 2006-2009 Joshua D Bartlett
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

from trosnoth.src.gui.fonts import fontcache

class Font(object):
    def __init__(self, name, size):
        self._name = name
        self._size = size

    # TODO: could cache resulting images        
    def render(self, app, text, antialias, colour, background=None):
        if background==None:
            return self._getFont(app).render(text, antialias, colour)
        else:
            return self._getFont(app).render(text, antialias, colour, background)

    def size(self, app, text):
        return self._getFont(app).size(text)

    def getLineSize(self, app):
        return self._getFont(app).get_linesize()

    def getHeight(self, app):
        return self._getFont(app).get_height()
        
    def _getFont(self, app):
        return fontcache.get(self._name, self._size)

    def __repr__(self):
        return "Font: %s size %d" % (self._name, self._size)

class ScaledFont(Font):
    def _getFont(self, app):
        return fontcache.get(self._name, int(self._size * app.screenManager.scaleFactor + 0.5))

    def __repr__(self):
        return "Scaled Font: %s size %d" % (self._name, self._size)

==> trosnoth-1.2.2.tar.gz: trosnoth-1.2.2/trosnoth/src/gui/fonts/font.py <==
# Trosnoth (UberTweak Platform Game)
# Copyright (C) 2006-2009 Joshua D Bartlett
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

from trosnoth.src.gui.fonts import fontcache

class Font(object):
    def __init__(self, name, size):
        self._name = name
        self._size = size

    # TODO: could cache resulting images        
    def render(self, app, text, antialias, colour, background=None):
        if background==None:
            return self._getFont(app).render(text, antialias, colour)
        else:
            return self._getFont(app).render(text, antialias, colour, background)

    def size(self, app, text):
        return self._getFont(app).size(text)

    def getLineSize(self, app):
        return self._getFont(app).get_linesize()

    def getHeight(self, app):
        return self._getFont(app).get_height()
        
    def _getFont(self, app):
        filename = app.getFontFilename(self._name)
        return fontcache.get(filename, self._size)

    def __repr__(self):
        return "Font: %s size %d" % (self._name, self._size)

class ScaledFont(Font):
    def _getFont(self, app):
        filename = app.getFontFilename(self._name)
        return fontcache.get(filename,
                int(self._size * app.screenManager.scaleFactor + 0.5))

    def __repr__(self):
        return "Scaled Font: %s size %d" % (self._name, self._size)
